@@ -51,6 +51,8 @@ CACmdLnOptions::CACmdLnOptions()
 		m_cnTargets=0;
 		m_arListenerInterfaces=NULL;
 		m_cnListenerInterfaces=0;
+		m_arStrVisibleAddresses=NULL;
+		m_cnVisibleAddresses=0;
 		m_nrOfOpenFiles=-1;
 		m_strMixID=NULL;
 		m_pSignKey=NULL;
@@ -65,6 +67,14 @@ CACmdLnOptions::CACmdLnOptions()
 		m_bIsEncryptedLogEnabled=false;
 		m_pcsReConfigure=new CAMutex();
 		m_strPidFile=NULL;
+#ifdef PAYMENT
+		m_pBI=NULL;
+		m_strDatabaseHost=NULL;
+		m_strDatabaseName=NULL;
+		m_strDatabaseUser=NULL;
+		m_strDatabasePassword=NULL;
+		m_strAiID=NULL;
+#endif
  }
 
 CACmdLnOptions::~CACmdLnOptions()
@@ -111,6 +121,86 @@ SINT32 CACmdLnOptions::clearListenerInterfaces()
 		return E_SUCCESS;
 	}
 
+/** Deletes all information about the visible addresses.
+	*/
+SINT32 CACmdLnOptions::clearVisibleAddresses()
+	{
+		if(m_arStrVisibleAddresses!=NULL)
+			{
+				for(UINT32 i=0;i<m_cnVisibleAddresses;i++)
+					delete[] m_arStrVisibleAddresses[i];
+				delete[] m_arStrVisibleAddresses;
+			}
+		m_cnVisibleAddresses=0;
+		m_arStrVisibleAddresses=NULL;
+		return E_SUCCESS;
+	}
+
+/** Add all the visible addresses to the list of visible addresses found in the XML description of the <Proxy> element given.
+	* The structur is as follows:
+	* <Proxy>
+	*      <VisibleAddresses> <!-- Describes the visible addresses from the 'outside world' -->
+ *       <VisibleAddress>
+  *        <Host> <!-- Host or IP -->
+   *       </Host>
+   *     </VisibleAddress>
+   *   </VisibleAddresses>
+*
+	* </Proxy>
+	*/
+SINT32 CACmdLnOptions::addVisibleAddresses(DOM_Node& nodeProxy)
+	{
+		if(nodeProxy==NULL)
+			return E_UNKNOWN;
+		if(!nodeProxy.getNodeName().equals("Proxy"))
+			return E_UNKNOWN;
+		DOM_Node elemVisAdresses;
+		getDOMChildByName(nodeProxy,(UINT8*)"VisibleAddresses",elemVisAdresses);
+		DOM_Node elemVisAddress;
+		getDOMChildByName(elemVisAdresses,(UINT8*)"VisibleAddress",elemVisAddress);
+		while(elemVisAddress!=NULL)
+			{
+				if(elemVisAddress.getNodeName().equals("VisibleAddress"))
+					{
+						DOM_Element elemHost;
+						if(getDOMChildByName(elemVisAddress,(UINT8*)"Host",elemHost)==E_SUCCESS)
+							{
+								UINT8 tmp[255];
+								UINT32 len=255;
+								if(getDOMElementValue(elemHost,tmp,&len)==E_SUCCESS)
+									{//append the new address to the list of addresses
+										UINT8** tmpAr=new UINT8*[m_cnVisibleAddresses+1];
+										if(m_arStrVisibleAddresses!=NULL)
+											{
+												memcpy(tmpAr,m_arStrVisibleAddresses,m_cnVisibleAddresses*sizeof(UINT8*));
+												delete[] m_arStrVisibleAddresses;
+											}
+										tmpAr[m_cnVisibleAddresses]=new UINT8[len+1];
+										memcpy(tmpAr[m_cnVisibleAddresses],tmp,len+1);
+										m_cnVisibleAddresses++;
+										m_arStrVisibleAddresses=tmpAr;	
+									}
+							}
+					}
+				elemVisAddress=elemVisAddress.getNextSibling();	
+			}
+		return E_SUCCESS;
+	}
+
+SINT32 CACmdLnOptions::getVisibleAddress(UINT8* strAddressBuff, UINT32 len,UINT32 nr)
+	{
+		if(strAddressBuff==NULL||nr==0||nr>m_cnVisibleAddresses)
+			{
+				return E_UNKNOWN;
+			}
+		if(strlen((char*)m_arStrVisibleAddresses[nr-1]	)>=len)
+			{
+				return E_SPACE;
+			}
+		strcpy((char*)strAddressBuff,(char*)m_arStrVisibleAddresses[nr-1]);
+		return E_SUCCESS;	
+	}
+
 void CACmdLnOptions::clean()
   {
 		if(m_strConfigFile!=NULL)
@@ -155,6 +245,7 @@ void CACmdLnOptions::clean()
 		m_strMixID=NULL;
 		clearTargetInterfaces();
 		clearListenerInterfaces();
+		clearVisibleAddresses();
 		if(m_pSignKey!=NULL)
 			delete m_pSignKey;
 		m_pSignKey=NULL;
@@ -267,19 +358,19 @@ SINT32 CACmdLnOptions::parse(int argc,const char** argv)
 				else
 					{
 						char tmpHostname[255];
-						int tmpPort;
+						SINT32 tmpPort;
 						char* tmpStr1=strchr(target,':');
 						if(tmpStr1!=NULL)
 							{
 								memcpy(tmpHostname,target,tmpStr1-target);
 								tmpHostname[tmpStr1-target]=0;
-								tmpPort=(int)atol(tmpStr1+1);
+								tmpPort=(SINT32)atol(tmpStr1+1);
 							}
 						else
 							{//TODO what if not in right form ?
 								//try if it is a number --> use it as port
 								//and use 'localhost' as traget-host
-								tmpPort=(int)atol(target);
+								tmpPort=(SINT32)atol(target);
 								if(tmpPort!=0) //we get it
 									{
 										strcpy(tmpHostname,"localhost");
@@ -293,7 +384,7 @@ SINT32 CACmdLnOptions::parse(int argc,const char** argv)
 							}
 						m_strTargetHost=new char[strlen(tmpHostname)+1];
 						strcpy(m_strTargetHost,tmpHostname);
-						m_iTargetPort=tmpPort;
+						m_iTargetPort=(UINT16)tmpPort;
 					}
 				free(target);
 	    }
@@ -301,12 +392,12 @@ SINT32 CACmdLnOptions::parse(int argc,const char** argv)
 			{
 				char* tmpStr;
 				if((tmpStr=strchr(socks,':'))!=NULL)
-						{
-					m_strSOCKSHost=new char[tmpStr-socks+1];
-					(*tmpStr)=0;
-					strcpy(m_strSOCKSHost,socks);
-					m_iSOCKSPort=(int)atol(tmpStr+1);
-						}
+					{
+						m_strSOCKSHost=new char[tmpStr-socks+1];
+						(*tmpStr)=0;
+						strcpy(m_strSOCKSHost,socks);
+						m_iSOCKSPort=(UINT16)atol(tmpStr+1);
+					}
 				free(socks);
 	    }
 	if(logdir!=NULL)
@@ -338,19 +429,19 @@ SINT32 CACmdLnOptions::parse(int argc,const char** argv)
 			else //Internet Socket
 				{
 					char* strServerHost=NULL;
-					int iServerPort;
+					SINT32 iServerPort;
 					if((tmpStr=strchr(serverPort,':'))!=NULL) //host:port
 						{
 							strServerHost=new char[tmpStr-serverPort+1];
 							(*tmpStr)=0;
 							strcpy(strServerHost,serverPort);
-							iServerPort=(int)atol(tmpStr+1);
+							iServerPort=(SINT32)atol(tmpStr+1);
 						}
 					else //port only ?
 						{
-							iServerPort=(int)atol(serverPort);
+							iServerPort=(SINT32)atol(serverPort);
 						}
-						m_arListenerInterfaces[0]=CAListenerInterface::getInstance(RAW_TCP,(UINT8*)strServerHost,iServerPort);
+						m_arListenerInterfaces[0]=CAListenerInterface::getInstance(RAW_TCP,(UINT8*)strServerHost,(UINT16)iServerPort);
 					delete [] strServerHost;
 				}
 			free(serverPort);
@@ -358,7 +449,7 @@ SINT32 CACmdLnOptions::parse(int argc,const char** argv)
 				m_cnListenerInterfaces=1;
 		}
 
-	m_iSOCKSServerPort=SOCKSport;
+	m_iSOCKSServerPort=(UINT16)SOCKSport;
 	if(!m_bLocalProxy)
 		{
 			ret=processXmlConfiguration(m_docMixXml);
@@ -561,6 +652,7 @@ SINT32 CACmdLnOptions::setPrevMix(DOM_Document& doc)
 /** Rereads the configuration file (if one was given on startup) and reconfigures
 	* the mix according to the new values. This is done asyncronous. A new thread is
 	* started, which does the actual work.
+	* Note: We have to avoid an blocking on any mutex, as this function typically is called from a signal handler - and who knows which mutexes are blocked if this happend...
 	* @retval E_SUCCESS if successful
 	* @retval E_UNKNOWN if an error occurs
 	*/
@@ -568,17 +660,12 @@ SINT32 CACmdLnOptions::reread(CAMix* pMix)
 	{
 		if(m_bIsRunReConfigure)
 			return E_UNKNOWN;
-		//CAMsg::printMsg(LOG_DEBUG,"Re-readed before lock\n");
-		//m_pcsReConfigure->lock();
-		//CAMsg::printMsg(LOG_DEBUG,"Re-readed after lock\n");
 		m_bIsRunReConfigure=true;
 		m_threadReConfigure.setMainLoop(threadReConfigure);
-		CAMsg::printMsg(LOG_DEBUG,"Re-read After set thread loop\n");
 		t_CMNDLN_REREAD_PARAMS* param=new t_CMNDLN_REREAD_PARAMS;
 		param->pCmdLnOptions=this;
 		param->pMix=pMix;
-		m_threadReConfigure.start(param,true);
-		//m_pcsReConfigure->unlock();
+		m_threadReConfigure.start(param,true,false);
 		return E_SUCCESS;
 	}
 
@@ -671,75 +758,80 @@ SINT32 CACmdLnOptions::getSOCKSHost(UINT8* host,UINT32 len)
   }
 
 #ifdef PAYMENT
-CAXMLBI * CACmdLnOptions::getBI()
-			{
+/**Returns an CAXMLBI object, which describes the BI this AI uses. This is not a copy of the 
+  * CAXMLBI object. The caller should not delete it!
+	* @retval NULL if BI was not set in the configuration file
+	* @return information stored inthe configuration file about the BI
+	*/
+CAXMLBI* CACmdLnOptions::getBI()
+	{
 		return m_pBI;
-			}
+	}
 
 SINT32 CACmdLnOptions::getDatabaseHost(UINT8 * host, UINT32 len)
-{
-	if(m_strDatabaseHost==NULL)
+	{
+		if(m_strDatabaseHost==NULL)
 			return E_UNKNOWN;
-	if(len<=(UINT32)strlen((char *)m_strDatabaseHost))
+		if(len<=(UINT32)strlen((char *)m_strDatabaseHost))
 			{
 				return E_UNKNOWN;
 			}
-	strcpy((char*)host,(char *)m_strDatabaseHost);
-	return (SINT32)strlen((char *)m_strDatabaseHost);	
+		strcpy((char*)host,(char *)m_strDatabaseHost);
+		return E_SUCCESS;	
 }
 
 UINT16 CACmdLnOptions::getDatabasePort()
-{
-	return m_iDatabasePort;
-}
+	{
+		return m_iDatabasePort;
+	}
 
 SINT32 CACmdLnOptions::getDatabaseName(UINT8 * name, UINT32 len)
-{
-	if(m_strDatabaseName==NULL)
+	{
+		if(m_strDatabaseName==NULL)
 			return E_UNKNOWN;
-	if(len<=(UINT32)strlen((char *)m_strDatabaseName))
+		if(len<=(UINT32)strlen((char *)m_strDatabaseName))
 			{
 				return E_UNKNOWN;
 			}
-	strcpy((char*)name,(char *)m_strDatabaseName);
-	return (SINT32)strlen((char *)m_strDatabaseName);	
-}
+		strcpy((char*)name,(char *)m_strDatabaseName);
+		return E_SUCCESS;	
+	}
 
 SINT32 CACmdLnOptions::getDatabaseUsername(UINT8 * user, UINT32 len)
-{
-	if(m_strDatabaseUser==NULL)
+	{
+		if(m_strDatabaseUser==NULL)
 			return E_UNKNOWN;
-	if(len<=(UINT32)strlen((char *)m_strDatabaseUser))
+		if(len<=(UINT32)strlen((char *)m_strDatabaseUser))
 			{
 				return E_UNKNOWN;
 			}
-	strcpy((char*)user,(char *)m_strDatabaseUser);
-	return (SINT32)strlen((char *)m_strDatabaseUser);	
-}
+		strcpy((char*)user,(char *)m_strDatabaseUser);
+		return E_SUCCESS;	
+	}
 
 SINT32 CACmdLnOptions::getDatabasePassword(UINT8 * pass, UINT32 len)
-{
-	if(m_strDatabasePassword==NULL)
+	{
+		if(m_strDatabasePassword==NULL)
 			return E_UNKNOWN;
-	if(len<=(UINT32)strlen((char *)m_strDatabasePassword))
+		if(len<=(UINT32)strlen((char *)m_strDatabasePassword))
 			{
 				return E_UNKNOWN;
 			}
-	strcpy((char*)pass,(char *)m_strDatabasePassword);
-	return (SINT32)strlen((char *)m_strDatabasePassword);	
-}
+		strcpy((char*)pass,(char *)m_strDatabasePassword);
+		return E_SUCCESS;	
+	}
 
 SINT32 CACmdLnOptions::getAiID(UINT8 * id, UINT32 len)
-{
-	if(m_strAiID==NULL)
+	{
+		if(m_strAiID==NULL)
 			return E_UNKNOWN;
-	if(len<=(UINT32)strlen((char *)m_strAiID))
+		if(len<=(UINT32)strlen((char *)m_strAiID))
 			{
 				return E_UNKNOWN;
 			}
-	strcpy((char*)id,(char *)m_strAiID);
-	return (SINT32)strlen((char *)m_strAiID);
-}
+		strcpy((char*)id,(char *)m_strAiID);
+		return E_SUCCESS;
+	}
 
 SINT32 CACmdLnOptions::getPaymentHardLimit(UINT32 *pHardLimit)
 	{
@@ -1057,77 +1149,72 @@ SINT32 CACmdLnOptions::processXmlConfiguration(DOM_Document& docConfig)
 
 		DOM_Element elemAccounting;
 		getDOMChildByName(elemRoot,(UINT8*)"Accounting",elemAccounting,false);
-		if(elemAccounting != NULL) {
-			DOM_Element elemJPI;
-			CAXMLBI * pBI=0;
-			getDOMChildByName(elemAccounting, CAXMLBI::getXMLElementName(), elemJPI, false);
-			if(elemJPI!=NULL)
-				pBI = new CAXMLBI(elemJPI);
-			if(pBI)
-				m_pBI = pBI;
-			else
-				m_pBI = 0;
-			
-		
-			getDOMChildByName(elemAccounting, (UINT8*)"SoftLimit", elem, false);
-			if(getDOMElementValue(elem, &tmp)==E_SUCCESS)
+		if(elemAccounting != NULL) 
 			{
-				m_iPaymentSoftLimit = tmp;
-				}
-				
-			getDOMChildByName(elemAccounting, (UINT8*)"HardLimit", elem, false);
-			if(getDOMElementValue(elem, &tmp)==E_SUCCESS)
-			{
-				m_iPaymentHardLimit = tmp;
-			}
-			getDOMChildByName(elemAccounting, (UINT8*)"SettleInterval", elem, false);
-			if(getDOMElementValue(elem, &tmp)==E_SUCCESS)
-			{
-				m_iPaymentSettleInterval = tmp;
-				}
-			
-			// get DB Username
-			getDOMChildByName(elemAccounting, (UINT8*)"AiID", elem, false);
-			tmpLen = 255;
-			if(getDOMElementValue(elem, tmpBuff, &tmpLen)==E_SUCCESS) {
-				strtrim(tmpBuff);
-				m_strAiID = new UINT8[strlen((char*)tmpBuff)+1];
-				strcpy((char *)m_strAiID, (char *) tmpBuff);
-			}
-
-			
-			DOM_Element elemDatabase;
-			getDOMChildByName(elemAccounting, (UINT8*)"Database", elemDatabase, false);
-			if(elemDatabase != NULL) {
-				// get DB Hostname
-				getDOMChildByName(elemDatabase, (UINT8*)"Host", elem, false);
-				tmpLen = 255;
-				if(getDOMElementValue(elem, tmpBuff, &tmpLen)==E_SUCCESS) {
-					strtrim(tmpBuff);
-					m_strDatabaseHost = new UINT8[strlen((char*)tmpBuff)+1];
-					strcpy((char *)m_strDatabaseHost, (char *) tmpBuff);
-				}
-				// get Database Port
-				getDOMChildByName(elemDatabase, (UINT8*)"Port", elem, false);
-				if(getDOMElementValue(elem, &tmp)==E_SUCCESS) {
-					m_iDatabasePort = tmp;
-				}
-				// get DB Name
-				getDOMChildByName(elemDatabase, (UINT8*)"DBName", elem, false);
-				tmpLen = 255;
-				if(getDOMElementValue(elem, tmpBuff, &tmpLen)==E_SUCCESS) {
-					strtrim(tmpBuff);
-					m_strDatabaseName = new UINT8[strlen((char*)tmpBuff)+1];
-					strcpy((char *)m_strDatabaseName, (char *) tmpBuff);
-				}
+				DOM_Element elemJPI;
+				getDOMChildByName(elemAccounting, CAXMLBI::getXMLElementName(), elemJPI, false);
+				m_pBI = CAXMLBI::getInstance(elemJPI);
+				getDOMChildByName(elemAccounting, (UINT8*)"SoftLimit", elem, false);
+				if(getDOMElementValue(elem, &tmp)==E_SUCCESS)
+					{
+						m_iPaymentSoftLimit = tmp;
+					}
+				getDOMChildByName(elemAccounting, (UINT8*)"HardLimit", elem, false);
+				if(getDOMElementValue(elem, &tmp)==E_SUCCESS)
+					{
+						m_iPaymentHardLimit = tmp;
+					}
+				getDOMChildByName(elemAccounting, (UINT8*)"SettleInterval", elem, false);
+				if(getDOMElementValue(elem, &tmp)==E_SUCCESS)
+					{
+						m_iPaymentSettleInterval = tmp;
+					}
 				// get DB Username
-				getDOMChildByName(elemDatabase, (UINT8*)"Username", elem, false);
+				getDOMChildByName(elemAccounting, (UINT8*)"AiID", elem, false);
 				tmpLen = 255;
-				if(getDOMElementValue(elem, tmpBuff, &tmpLen)==E_SUCCESS) {
-					strtrim(tmpBuff);
-					m_strDatabaseUser = new UINT8[strlen((char*)tmpBuff)+1];
-					strcpy((char *)m_strDatabaseUser, (char *) tmpBuff);
-				}
+				if(getDOMElementValue(elem, tmpBuff, &tmpLen)==E_SUCCESS) 
+					{
+						strtrim(tmpBuff);
+						m_strAiID = new UINT8[strlen((char*)tmpBuff)+1];
+						strcpy((char *)m_strAiID, (char *) tmpBuff);
+					}
+				DOM_Element elemDatabase;
+				getDOMChildByName(elemAccounting, (UINT8*)"Database", elemDatabase, false);
+				if(elemDatabase != NULL) 
+					{
+						// get DB Hostname
+						getDOMChildByName(elemDatabase, (UINT8*)"Host", elem, false);
+						tmpLen = 255;
+						if(getDOMElementValue(elem, tmpBuff, &tmpLen)==E_SUCCESS) 
+							{
+								strtrim(tmpBuff);
+								m_strDatabaseHost = new UINT8[strlen((char*)tmpBuff)+1];
+								strcpy((char *)m_strDatabaseHost, (char *) tmpBuff);
+							}
+						// get Database Port
+						getDOMChildByName(elemDatabase, (UINT8*)"Port", elem, false);
+						if(getDOMElementValue(elem, &tmp)==E_SUCCESS) 
+							{
+								m_iDatabasePort = tmp;
+							}
+						// get DB Name
+						getDOMChildByName(elemDatabase, (UINT8*)"DBName", elem, false);
+						tmpLen = 255;
+						if(getDOMElementValue(elem, tmpBuff, &tmpLen)==E_SUCCESS) 
+							{
+								strtrim(tmpBuff);
+								m_strDatabaseName = new UINT8[strlen((char*)tmpBuff)+1];
+								strcpy((char *)m_strDatabaseName, (char *) tmpBuff);
+							}
+						// get DB Username
+						getDOMChildByName(elemDatabase, (UINT8*)"Username", elem, false);
+						tmpLen = 255;
+						if(getDOMElementValue(elem, tmpBuff, &tmpLen)==E_SUCCESS) 
+							{
+								strtrim(tmpBuff);
+								m_strDatabaseUser = new UINT8[strlen((char*)tmpBuff)+1];
+								strcpy((char *)m_strDatabaseUser, (char *) tmpBuff);
+							}
 /*				getDOMChildByName(elemDatabase, (UINT8*)"Password", elem, false);
 				tmpLen = 255;
 				if(getDOMElementValue(elem, tmpBuff, &tmpLen)==E_SUCCESS) {
@@ -1136,26 +1223,27 @@ SINT32 CACmdLnOptions::processXmlConfiguration(DOM_Document& docConfig)
 					strcpy(m_strDatabasePassword, (char *) tmpBuff);
 				}*/
 				// don't read password from XML but from stdin:
-				UINT8 dbpass[500];
-				dbpass[0]=0;
-				printf("Please enter password for postgresql user %s at %s: ",m_strDatabaseUser, m_strDatabaseHost);
-				scanf("%400[^\n]%*1[\n]",(char*)dbpass); 
-				int len = strlen((char *)dbpass);
-				if(len>0) 
-				{
-					m_strDatabasePassword = new UINT8[len+1];
-					strcpy((char *)m_strDatabasePassword, (char *)dbpass);
+						UINT8 dbpass[500];
+						dbpass[0]=0;
+						printf("Please enter password for postgresql user %s at %s: ",m_strDatabaseUser, m_strDatabaseHost);
+						scanf("%400[^\n]%*1[\n]",(char*)dbpass); 
+						int len = strlen((char *)dbpass);
+						if(len>0) 
+							{
+								m_strDatabasePassword = new UINT8[len+1];
+								strcpy((char *)m_strDatabasePassword, (char *)dbpass);
+							}
+						else
+							{
+								m_strDatabasePassword = new UINT8[1];
+								m_strDatabasePassword[0] = '\0';
+							}	
 				}
-				else
-				{
-					m_strDatabasePassword = new UINT8[1];
-					m_strDatabasePassword[0] = '\0';
-				}	
+		}
+		else 
+			{
+				CAMsg::printMsg( 17, "No accounting instance info found in configfile. Payment will not work!\n");
 			}
-		}
-		else {
-			CAMsg::printMsg( 17, "No accounting instance info found in configfile. Payment will not work!");
-		}
 
 #endif /* ifdef PAYMENT */
 
@@ -1181,7 +1269,7 @@ SINT32 CACmdLnOptions::processXmlConfiguration(DOM_Document& docConfig)
 			}
 		getDOMChildByName(elemInfoService,(UINT8*)"Port",elem,false);
 		if(getDOMElementValue(elem,&tmp)==E_SUCCESS)
-			m_iInfoServerPort=tmp;
+			m_iInfoServerPort=(UINT16)tmp;
 
 		//get ListenerInterfaces
 		DOM_Element elemListenerInterfaces;
@@ -1296,7 +1384,8 @@ SKIP_NEXT_MIX:
 				delete addr;
 			}
 
-		//Next Proxies
+		//Next Proxies and visible adresses
+		clearVisibleAddresses();
 		DOM_Element elemProxies;
 		getDOMChildByName(elemNetwork,(UINT8*)"Proxies",elemProxies,false);
 		if(elemProxies!=NULL)
@@ -1389,6 +1478,7 @@ SKIP_NEXT_MIX:
 		#else
 									continue;
 		#endif
+								addVisibleAddresses(elemTargetInterface);
 								m_arTargetInterfaces[aktInterface].net_type=type;
 								m_arTargetInterfaces[aktInterface].target_type=proxy_type;
 								m_arTargetInterfaces[aktInterface].addr=addr->clone();
@@ -1412,6 +1502,7 @@ SKIP_NEXT_MIX:
 				m_arTargetInterfaces[m_cnTargets++].addr=targetInterfaceNextMix->addr;
 				delete targetInterfaceNextMix;
 			}
+		//-----------------------------------------------------------------------------	
 		//construct a XML-String, which describes the Mix (send via Infoservice.Helo())
 		m_docMixInfo=DOM_Document::createDocument();
 		DOM_Element elemMix=m_docMixInfo.createElement("Mix");
@@ -1459,6 +1550,30 @@ SKIP_NEXT_MIX:
     // -- inserted by ronin <ronin2@web.de> 2004-08-16
     elemMix.appendChild(m_docMixInfo.importNode(elemListenerInterfaces,true));
 
+		//Set Proxy Visible Addresses if Last Mix and given
+		if(isLastMix())
+			{
+				DOM_Element elemProxies=m_docMixInfo.createElement("Proxies");
+				DOM_Element elemProxy=m_docMixInfo.createElement("Proxy");
+				DOM_Element elemVisAddresses=m_docMixInfo.createElement("VisibleAddresses");
+				elemMix.appendChild(elemProxies);
+				elemProxies.appendChild(elemProxy);
+				elemProxy.appendChild(elemVisAddresses);
+				for(UINT32 i=1;i<=getVisibleAddressesCount();i++)
+					{
+						UINT8 tmp[255];
+						UINT32 tmplen=255;
+						if(getVisibleAddress(tmp,tmplen,i)==E_SUCCESS)
+							{
+								DOM_Element elemVisAddress=m_docMixInfo.createElement("VisibleAddress");
+								DOM_Element elemHost=m_docMixInfo.createElement("Host");
+								elemVisAddress.appendChild(elemHost);
+								setDOMElementValue(elemHost,tmp);
+								elemVisAddresses.appendChild(elemVisAddress);
+							}
+					}
+			}
+		
 		//Set Software-Version...
 		DOM_Element elemSoftware=m_docMixInfo.createElement("Software");
 		DOM_Element elemVersion=m_docMixInfo.createElement("Version");
@@ -1604,7 +1719,7 @@ SKIP_NEXT_MIX:
         getDOMChildByName(elemRoot,(UINT8*)"MixCascade",m_oCascadeXML,false);
 
         DOM_NodeList nl = m_oCascadeXML.getElementsByTagName("Mix");
-        UINT16 len = nl.getLength();
+        UINT16 len = (UINT16)nl.getLength();
         if(len == 0)
         {
             CAMsg::printMsg(LOG_CRIT,"Error in configuration: Empty cascade specified.\n");
