@@ -189,11 +189,6 @@ SINT32 CAFirstMix::init()
         CAMsg::printMsg(LOG_CRIT,"Error in establishing secure communication with next Mix!\n");
         return E_UNKNOWN;
     }
-
-#ifdef PAYMENT
-		m_pAccountingInstance = CAAccountingInstance::getInstance();
-#endif
-
 		m_pIPList=new CAIPList();
 #ifdef COUNTRY_STATS
 		initCountryStats();
@@ -213,6 +208,11 @@ SINT32 CAFirstMix::init()
 #ifdef REPLAY_DETECTION
 		m_pReplayMsgProc=new CAReplayCtrlChannelMsgProc(this);
 #endif
+
+#ifdef PAYMENT
+		CAAccountingInstance::init();
+#endif
+
 		m_pthreadsLogin=new CAThreadPool(NUM_LOGIN_WORKER_TRHEADS,MAX_LOGIN_QUEUE,false);
 
 		//Starting thread for Step 1
@@ -252,7 +252,7 @@ SINT32 CAFirstMix::processKeyExchange()
     UINT16 len;
 
 
-    if(((CASocket*)(*m_pMuxOut))->receiveFully((UINT8*)&len,2)!=E_SUCCESS)
+    if(m_pMuxOut->receiveFully((UINT8*)&len,2)!=E_SUCCESS)
     {
         CAMsg::printMsg(LOG_CRIT,"Error receiving Key Info lenght!\n");
         return E_UNKNOWN;
@@ -261,7 +261,7 @@ SINT32 CAFirstMix::processKeyExchange()
     CAMsg::printMsg(LOG_CRIT,"Received Key Info lenght %u\n",len);
     recvBuff=new UINT8[len+1];
 
-    if(((CASocket*)(*m_pMuxOut))->receiveFully(recvBuff,len)!=E_SUCCESS)
+    if(m_pMuxOut->receiveFully(recvBuff,len)!=E_SUCCESS)
     {
         CAMsg::printMsg(LOG_CRIT,"Error receiving Key Info!\n");
         delete []recvBuff;
@@ -303,7 +303,7 @@ SINT32 CAFirstMix::processKeyExchange()
     //tmp XML-Structure for constructing the XML which is send to each user
     DOM_Document docXmlKeyInfo=DOM_Document::createDocument();
     DOM_Element elemRootKey=docXmlKeyInfo.createElement("MixCascade");
-    setDOMElementAttribute(elemRootKey,"version",(UINT8*)"0.1"); //set the Version of the XML to 0.1
+    setDOMElementAttribute(elemRootKey,"version",(UINT8*)"0.2"); //set the Version of the XML to 0.2
     docXmlKeyInfo.appendChild(elemRootKey);
     DOM_Element elemMixProtocolVersion=docXmlKeyInfo.createElement("MixProtocolVersion");
     setDOMElementValue(elemMixProtocolVersion,(UINT8*)MIX_CASCADE_PROTOCOL_VERSION);
@@ -336,7 +336,17 @@ SINT32 CAFirstMix::processKeyExchange()
 		elemOwnMix.appendChild(docXmlKeyInfo.importNode(docfragKey,true));
     elemMixesKey.insertBefore(elemOwnMix,elemMixesKey.getFirstChild());
     setDOMElementAttribute((DOM_Element&)elemMixesKey,"count",count+1);
-    CACertificate* ownCert=options.getOwnCertificate();
+    
+	  DOM_Node elemPayment=docXmlKeyInfo.createElement("Payment");
+		elemRootKey.appendChild(elemPayment);
+		#ifdef PAYMENT
+			setDOMElementAttribute(elemPayment,"required",(UINT8*)"true");
+		#else
+			setDOMElementAttribute(elemPayment,"required",(UINT8*)"false");
+		#endif
+
+		//dign the xml struct send to each jap user
+		CACertificate* ownCert=options.getOwnCertificate();
     if(ownCert==NULL)
     {
         CAMsg::printMsg(LOG_DEBUG,"Own Test Cert is NULL -- so it could not be inserted into signed KeyInfo send to users...\n");
@@ -700,7 +710,7 @@ THREAD_RETURN fm_loopAcceptUsers(void* param)
 										ret=((CASocket*)pNewMuxSocket)->getPeerIP(peerIP);
 										#ifdef PAYMENT
 											if(ret!=E_SUCCESS||pIPList->insertIP(peerIP)<0 ||
-												pFirstMix->m_pAccountingInstance->isIPAddressBlocked(peerIP))
+												CAAccountingInstance::isIPAddressBlocked(peerIP))
 										#else
 											if(ret!=E_SUCCESS||pIPList->insertIP(peerIP)<0)
 										#endif
@@ -756,7 +766,7 @@ SINT32 CAFirstMix::doUserLogin(CAMuxSocket* pNewUser,UINT8 peerIP[4])
 		// es kann nicht blockieren unter der Annahme das der TCP-Sendbuffer > m_xmlKeyInfoSize ist....
 		//wait for keys from user
 		UINT16 xml_len;
-		if(((CASocket*)pNewUser)->receiveFully((UINT8*)&xml_len,2,FIRST_MIX_RECEIVE_SYM_KEY_FROM_JAP_TIME_OUT)!=E_SUCCESS)
+		if(((CASocket*)pNewUser)->receiveFullyT((UINT8*)&xml_len,2,FIRST_MIX_RECEIVE_SYM_KEY_FROM_JAP_TIME_OUT)!=E_SUCCESS)
 			{
 				delete pNewUser;
 				m_pIPList->removeIP(peerIP);
@@ -764,7 +774,7 @@ SINT32 CAFirstMix::doUserLogin(CAMuxSocket* pNewUser,UINT8 peerIP[4])
 			}
 		xml_len=ntohs(xml_len);
 		UINT8* xml_buff=new UINT8[xml_len+2]; //+2 for size...
-		if(((CASocket*)pNewUser)->receiveFully(xml_buff+2,xml_len,FIRST_MIX_RECEIVE_SYM_KEY_FROM_JAP_TIME_OUT)!=E_SUCCESS)
+		if(((CASocket*)pNewUser)->receiveFullyT(xml_buff+2,xml_len,FIRST_MIX_RECEIVE_SYM_KEY_FROM_JAP_TIME_OUT)!=E_SUCCESS)
 			{
 				delete pNewUser;
 				delete xml_buff;
@@ -809,8 +819,8 @@ SINT32 CAFirstMix::doUserLogin(CAMuxSocket* pNewUser,UINT8 peerIP[4])
 				return E_UNKNOWN;
 			}
 		//Sending Signature....
-		xml_buff[0]=xml_len>>8;
-		xml_buff[1]=xml_len&0xFF;
+		xml_buff[0]=(UINT8)(xml_len>>8);
+		xml_buff[1]=(UINT8)(xml_len&0xFF);
 		UINT8 sig[255];
 		UINT32 siglen=255;
 		m_pSignature->sign(xml_buff,xml_len+2,sig,&siglen);
@@ -825,20 +835,20 @@ SINT32 CAFirstMix::doUserLogin(CAMuxSocket* pNewUser,UINT8 peerIP[4])
 		setDOMElementValue(elemSigValue,sig);
 		u32=xml_len;
 		DOM_Output::dumpToMem(docSig,xml_buff+2,&u32);
-		xml_buff[0]=u32>>8;
-		xml_buff[1]=u32&0xFF;
+		xml_buff[0]=(UINT8)(u32>>8);
+		xml_buff[1]=(UINT8)(u32&0xFF);
 		((CASocket*)pNewUser)->send(xml_buff,u32+2);
 		delete xml_buff;
 		((CASocket*)pNewUser)->setNonBlocking(true);
 		CAQueue* tmpQueue=new CAQueue(sizeof(tQueueEntry));
-		if(m_pChannelList->add(pNewUser,peerIP,tmpQueue)!=E_SUCCESS)// adding user connection to mix->JAP channel list (stefan: sollte das nicht connection list sein? --> es handelt sich um eine Datenstruktu fr Connections/Channels ).
+		fmHashTableEntry* pHashEntry=m_pChannelList->add(pNewUser,peerIP,tmpQueue);
+		if(pHashEntry==NULL)// adding user connection to mix->JAP channel list (stefan: sollte das nicht connection list sein? --> es handelt sich um eine Datenstruktu fr Connections/Channels ).
 			{
 				m_pIPList->removeIP(peerIP);
 				delete tmpQueue;
 				delete pNewUser;
 				return E_UNKNOWN;
 			}
-		fmHashTableEntry* pHashEntry=m_pChannelList->get(pNewUser);
 #ifdef PAYMENT
 		// register AI control channel
 		//CAAccountingControlChannel * pTmp = new CAAccountingControlChannel(pHashEntry);
@@ -1030,6 +1040,9 @@ SINT32 CAFirstMix::clean()
 		if(m_pthreadSendToMix!=NULL)
 			delete m_pthreadSendToMix;
 		m_pthreadSendToMix=NULL;
+#ifdef PAYMENT
+		CAAccountingInstance::clean();
+#endif
 		#ifdef LOG_PACKET_TIMES
 		if(m_pLogPacketStats!=NULL)
 			delete m_pLogPacketStats;
