@@ -36,6 +36,8 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 #include "CASingleSocketGroup.hpp"
 #include "CALastMix.hpp"
 #include "CAHttpClient.hpp"
+#include "CACertificate.hpp"
+#include "CAXMLBI.hpp"
 
 extern CACmdLnOptions options;
 
@@ -44,7 +46,7 @@ const char * STRINGS_REQUEST_COMMANDS[3]={"configure","helo","mixinfo/"};
 
 static THREAD_RETURN InfoLoop(void *p)
 	{
-		CAMsg::printMsg(LOG_DEBUG, "CAInoService - InfoLoop() started\n");
+		CAMsg::printMsg(LOG_DEBUG, "CAInfoService - InfoLoop() started\n");
 		CAInfoService* pInfoService=(CAInfoService*)p;
 		int helocount=0;
 		bool bIsFirst=true; //send our own certifcate only the first time
@@ -500,7 +502,7 @@ SINT32 CAInfoService::sendCascadeHelo()
 						goto ERR;
 				//Receive answer --> 200 Ok or failure
 				//HTTP/1.1 200 Ok
-				if(oSocket.receiveFully(buffHeader,12,MIX_TO_INFOSERVICE_TIMEOUT)!=E_SUCCESS)
+				if(oSocket.receiveFullyT(buffHeader,12,MIX_TO_INFOSERVICE_TIMEOUT)!=E_SUCCESS)
 					goto ERR;
 				if(memcmp(buffHeader+9,"200",3)!=0)
 					goto ERR;
@@ -588,3 +590,73 @@ SINT32 CAInfoService::handleConfigEvent(DOM_Document& doc)
     return E_SUCCESS;
 }
 
+#ifdef PAYMENT
+/** Gets a payment instance from the InfoService.
+	@param a_pstrPIID id of the payment instacne for which the information is requested
+	@retval E_SUCCESS if succesful
+	@retval E_UNKNOWN if an error occured
+	@return a_pXMLBI will point to a pointer to the newly created CAXMLBI object or to NULL
+*/
+SINT32 CAInfoService::getPaymentInstance(const UINT8* a_pstrPIID,CAXMLBI** a_pXMLBI)
+	{
+		CASocket socket;
+		CASocketAddrINet address;
+		UINT8 hostname[255];
+		UINT8 request[255];
+		CAHttpClient httpClient;
+		UINT32 status, contentLength;
+	
+		//Connect to InfoService
+		if(options.getInfoServerHost(hostname,255)!=E_SUCCESS)
+			return E_UNKNOWN;
+	
+		address.setAddr(hostname,options.getInfoServerPort());
+	
+		if(socket.connect(address)!=E_SUCCESS)
+			return E_UNKNOWN;
+	
+		#ifdef DEBUG
+			CAMsg::printMsg(LOG_DEBUG, "CAInfoService::getPaymentInstance() - connected to InfoService\n");
+		#endif
+	
+		//Send request
+		httpClient.setSocket(&socket);
+		sprintf((char*) request, "/paymentinstance/%s", (char*) a_pstrPIID);
+		httpClient.sendGetRequest(request);
+		httpClient.parseHTTPHeader(&contentLength, &status);
+		#ifdef DEBUG
+			CAMsg::printMsg(LOG_DEBUG, "CAInfoService::getPaymentInstance() - Request sent, HTTP status: %i, content length: %i\n", status, contentLength);
+		#endif	
+		if(status!=200||contentLength>0x00FFFF)
+			{
+				return E_UNKNOWN;
+			}
+			
+		UINT8* content=new UINT8[contentLength+1];
+		if(httpClient.getContent(content, &contentLength)!=E_SUCCESS)
+			{
+				delete []content;
+				return E_UNKNOWN;
+			}
+		socket.close();
+		//Parse XML
+		MemBufInputSource oInput( content, contentLength, "PaymentInstance" );
+		DOMParser oParser;
+		oParser.parse( oInput );
+		delete []content;
+		DOM_Document doc = oParser.getDocument();
+		if(doc==NULL)
+			return E_UNKNOWN;
+		DOM_Element elemRoot=doc.getDocumentElement();
+
+		*a_pXMLBI = CAXMLBI::getInstance(elemRoot);
+		if (*a_pXMLBI != NULL)
+			{
+				return E_SUCCESS;
+			}
+		else
+			{
+				return E_UNKNOWN;
+			}
+	}
+#endif
