@@ -183,9 +183,9 @@ SINT32 CALastMix::processKeyExchange()
 		DOM_Document doc=DOM_Document::createDocument();
 		DOM_Element elemMixes=doc.createElement("Mixes");
 		setDOMElementAttribute(elemMixes,"count",1);
-    UINT8 cName[128];
-    options.getCascadeName(cName,128);
-    setDOMElementAttribute(elemMixes,"cascadeName",cName);
+    //UINT8 cName[128];
+    //options.getCascadeName(cName,128);
+    //setDOMElementAttribute(elemMixes,"cascadeName",cName);
 		doc.appendChild(elemMixes);
 		DOM_Element elemMix=doc.createElement("Mix");
 		UINT8 idBuff[50];
@@ -337,7 +337,6 @@ SINT32 CALastMix::reconfigure()
 		#endif
 		#if defined (DELAY_CHANNELS_LATENCY)
 			UINT32 utemp=options.getDelayChannelLatency();
-			CAMsg::printMsg(LOG_DEBUG,"Set new latency: %u ms\n",utemp);
 			m_pChannelList->setDelayLatencyParameters(	utemp);
 		#endif
 		}
