@@ -31,7 +31,9 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 #include "CAMsg.hpp"
 #include "CACmdLnOptions.hpp"
 #include "CASocketAddrINet.hpp"
-#include "CASocketAddrUnix.hpp"
+#ifdef HAVE_UNIX_DOMAIN_PROTOCOL
+	#include "CASocketAddrUnix.hpp"
+#endif
 #include "CAThread.hpp"
 #include "CAInfoService.hpp"
 #include "CAUtil.hpp"
@@ -73,7 +75,7 @@ SINT32 CAMiddleMix::initOnce()
 	* @retval E_SUCCESS if KeyExchange with Mix \e n+1 and Mix \e n-1 was succesful
 	*	@retval E_UNKNOWN otherwise
 	*/
-SINT32 CAMiddleMix::proccessKeyExchange()
+SINT32 CAMiddleMix::processKeyExchange()
 	{
 		UINT8* recvBuff=NULL;		
 		UINT16 len;
@@ -329,6 +331,7 @@ SINT32 CAMiddleMix::init()
 				return E_UNKNOWN;		
 			}
 		
+    // connect to next mix    
 		CASocketAddr* pAddrNext=NULL;
 		for(UINT32 i=0;i<options.getTargetInterfaceCount();i++)
 			{
@@ -357,13 +360,6 @@ SINT32 CAMiddleMix::init()
 		((CASocket*)*m_pMuxOut)->setRecvBuff(50*MIXPACKET_SIZE);
 		((CASocket*)*m_pMuxOut)->setSendBuff(50*MIXPACKET_SIZE);
 
-//We now tell the worl that we are waiting...
-		if(m_pSignature!=NULL&&options.isInfoServiceEnabled())
-			{
-				m_pInfoService=new CAInfoService();
-				m_pInfoService->setSignature(m_pSignature);
-				m_pInfoService->start();
-			}
 #define RETRIES 100
 #define RETRYTIME 30
 		CAMsg::printMsg(LOG_INFO,"Init: Try to connect to next Mix...\n");
@@ -381,11 +377,25 @@ SINT32 CAMiddleMix::init()
 					CAMsg::printMsg(LOG_INFO,"Socket option KEEP-ALIVE returned an error - so also not set!\n");
 			}
 		
+    CAMsg::printMsg(LOG_INFO,"Waiting for Connection from previous Mix...\n");    
 		CAListenerInterface* pListener=NULL;
+		UINT32 interfaces=options.getListenerInterfaceCount();
+		for(UINT32 i=1;i<=interfaces;i++)
+			{
+				pListener=options.getListenerInterface(i);
+				if(!pListener->isVirtual())
+					break;
+				delete pListener;
+				pListener=NULL;
+			}
+		if(pListener==NULL)
+			{
+				CAMsg::printMsg(LOG_CRIT," failed!\n");
+				CAMsg::printMsg(LOG_CRIT,"Reason: no useable (non virtual) interface found!\n");
+				return E_UNKNOWN;
+			}
 		const CASocketAddr* pAddr=NULL;
-		pListener=options.getListenerInterface(1);
-		if(pListener!=NULL)
-			pAddr=pListener->getAddr();
+		pAddr=pListener->getAddr();
 		delete pListener;
 		m_pMuxIn=new CAMuxSocket();
 		SINT32 ret=m_pMuxIn->accept(*pAddr);
@@ -395,6 +405,7 @@ SINT32 CAMiddleMix::init()
 				CAMsg::printMsg(LOG_CRIT,"Error waiting for previous Mix... -- Exiting!\n");				
 				return E_UNKNOWN;
 			}
+		CAMsg::printMsg(LOG_INFO," connected!\n");
 		((CASocket*)*m_pMuxIn)->setRecvBuff(50*MIXPACKET_SIZE);
 		((CASocket*)*m_pMuxIn)->setSendBuff(50*MIXPACKET_SIZE);
 		if(((CASocket*)*m_pMuxIn)->setKeepAlive((UINT32)1800)!=E_SUCCESS)
@@ -404,11 +415,10 @@ SINT32 CAMiddleMix::init()
 					CAMsg::printMsg(LOG_INFO,"Socket option KEEP-ALIVE returned an error - so also not set!\n");
 			}
 		
-
-		if(proccessKeyExchange()!=E_SUCCESS)
+    if((ret = processKeyExchange())!=E_SUCCESS)
 			{
 				CAMsg::printMsg(LOG_CRIT,"Error in proccessKeyExchange()!\n");
-				return E_UNKNOWN;
+        return ret;
 			}
 	
 
@@ -424,19 +434,20 @@ THREAD_RETURN mm_loopDownStream(void *p)
 		CAMiddleMix* pMix=(CAMiddleMix*)p;
 		HCHANNEL channelIn;
 		CASymCipher* pCipher;
-		MIXPACKET* pMixPacket=new MIXPACKET;
+		tPoolEntry* pPoolEntry=new tPoolEntry;
+		MIXPACKET* pMixPacket=&pPoolEntry->packet;
 		SINT32 ret;
-		CASingleSocketGroup oSocketGroup;
+		CASingleSocketGroup oSocketGroup(false);
 		oSocketGroup.add(*(pMix->m_pMuxOut));
 #ifdef USE_POOL		
 		CAPool* pPool=new CAPool(MIX_POOL_SIZE);
 #endif
-		for(;;)
+		while(pMix->m_bRun)
 			{
-				#ifndef USE_POOL			
-					ret=oSocketGroup.select(false,1000);
+				#ifndef USE_POOL
+					ret=oSocketGroup.select(1000);
 				#else
-					ret=oSocketGroup.select(false,MIX_POOL_TIMEOUT);
+					ret=oSocketGroup.select(MIX_POOL_TIMEOUT);
 				#endif
 				if(ret!=1)
 					{
@@ -446,9 +457,9 @@ THREAD_RETURN mm_loopDownStream(void *p)
 									continue;
 								#else
 									pMixPacket->channel=DUMMY_CHANNEL;
-									pMixPacket->flags=CHANNEL_CLOSE;
+									pMixPacket->flags=CHANNEL_DUMMY;
 									getRandom(pMixPacket->data,DATA_SIZE);
-									pPool->pool(pMixPacket);
+									pPool->pool(pPoolEntry);
 									if(pMix->m_pMuxIn->send(pMixPacket)==SOCKET_ERROR)
 										goto ERR;								
 								#endif
@@ -475,9 +486,9 @@ THREAD_RETURN mm_loopDownStream(void *p)
 						#ifdef USE_POOL	
 							if(pMixPacket->channel==DUMMY_CHANNEL)
 								{
-									pMixPacket->flags=CHANNEL_CLOSE;
+									pMixPacket->flags=CHANNEL_DUMMY;
 									getRandom(pMixPacket->data,DATA_SIZE);
-									pPool->pool(pMixPacket);
+									pPool->pool(pPoolEntry);
 									if(pMix->m_pMuxIn->send(pMixPacket)==SOCKET_ERROR)
 										goto ERR;								
 								}
@@ -491,10 +502,10 @@ THREAD_RETURN mm_loopDownStream(void *p)
 									getRandom(pMixPacket->data,DATA_SIZE);
 								else
 								#endif
-								pCipher->decryptAES2(pMixPacket->data,pMixPacket->data,DATA_SIZE);
+								pCipher->crypt2(pMixPacket->data,pMixPacket->data,DATA_SIZE);
 								pCipher->unlock();
 								#ifdef USE_POOL
-									pPool->pool(pMixPacket);
+									pPool->pool(pPoolEntry);
 								#endif
 								if(pMix->m_pMuxIn->send(pMixPacket)==SOCKET_ERROR)
 									goto ERR;
@@ -502,13 +513,15 @@ THREAD_RETURN mm_loopDownStream(void *p)
 					}
 			}
 ERR:
-		CAMsg::printMsg(LOG_CRIT,"loopDownStream -- Exiting!\n");
-		delete pMixPacket;
+		CAMsg::printMsg(LOG_CRIT,"loopDownStream -- Exiting clean ups...\n");
+		pMix->m_bRun=false;
+		delete pPoolEntry;
 		#ifdef USE_POOL
 			delete pPool;
 		#endif
 		pMix->m_pMuxIn->close();
 		pMix->m_pMuxOut->close();
+		CAMsg::printMsg(LOG_CRIT,"loopDownStream -- Now Exiting!\n");
 #endif //!NEW_MIX_TYPE
 		THREAD_RETURN_SUCCESS;		
 	}
@@ -517,27 +530,29 @@ ERR:
 SINT32 CAMiddleMix::loop()
 	{
 #ifndef NEW_MIX_TYPE
-		MIXPACKET* pMixPacket=new MIXPACKET;
+		tPoolEntry* pPoolEntry=new tPoolEntry;
+		MIXPACKET* pMixPacket=&pPoolEntry->packet;
 		HCHANNEL channelOut;
 		CASymCipher* pCipher;
 		SINT32 ret;
 		UINT8* tmpRSABuff=new UINT8[RSA_SIZE];
-		CASingleSocketGroup oSocketGroup;
+		CASingleSocketGroup oSocketGroup(false);
 		oSocketGroup.add(*m_pMuxIn);
 		m_pMuxIn->setCrypt(true);
 		m_pMuxOut->setCrypt(true);
 		#ifdef USE_POOL		
 			CAPool* pPool=new CAPool(MIX_POOL_SIZE);
 		#endif
+		m_bRun=true;
 		CAThread oThread;
 		oThread.setMainLoop(mm_loopDownStream);
 		oThread.start(this);
-		for(;;)
+		while(m_bRun)
 			{
 				#ifndef USE_POOL			
-					ret=oSocketGroup.select(false,1000);
+					ret=oSocketGroup.select(1000);
 				#else
-					ret=oSocketGroup.select(false,MIX_POOL_TIMEOUT);
+					ret=oSocketGroup.select(MIX_POOL_TIMEOUT);
 				#endif
 				if(ret!=1)
 					{
@@ -547,9 +562,9 @@ SINT32 CAMiddleMix::loop()
 									continue;
 								#else
 									pMixPacket->channel=DUMMY_CHANNEL;
-									pMixPacket->flags=CHANNEL_CLOSE;
+									pMixPacket->flags=CHANNEL_DUMMY;
 									getRandom(pMixPacket->data,DATA_SIZE);
-									pPool->pool(pMixPacket);
+									pPool->pool(pPoolEntry);
 									if(m_pMuxOut->send(pMixPacket)==SOCKET_ERROR)
 										goto ERR;								
 								#endif
@@ -576,9 +591,9 @@ SINT32 CAMiddleMix::loop()
 						#ifdef USE_POOL	
 							if(pMixPacket->channel==DUMMY_CHANNEL)
 								{
-									pMixPacket->flags=CHANNEL_CLOSE;
+									pMixPacket->flags=CHANNEL_DUMMY;
 									getRandom(pMixPacket->data,DATA_SIZE);
-									pPool->pool(pMixPacket);
+									pPool->pool(pPoolEntry);
 									if(m_pMuxOut->send(pMixPacket)==SOCKET_ERROR)
 										goto ERR;								
 								}
@@ -593,22 +608,23 @@ SINT32 CAMiddleMix::loop()
 										#endif
 										m_pRSA->decrypt(pMixPacket->data,tmpRSABuff);
 										#ifdef REPLAY_DETECTION
-											if(!validTimestampAndFingerprint(tmpRSABuff, KEY_SIZE, (tmpRSABuff+KEY_SIZE)))
+											if(m_pReplayDB->insert(tmpRSABuff)!=E_SUCCESS)
 												{
-													CAMsg::printMsg(LOG_INFO,"Duplicate packet ignored.\n");
+													CAMsg::printMsg(LOG_INFO,"Replay: Duplicate packet ignored.\n");
 													continue;
 												}
 										#endif
 										pCipher=new CASymCipher();
-										pCipher->setKeyAES(tmpRSABuff);
-										pCipher->decryptAES(pMixPacket->data+RSA_SIZE,
-																				pMixPacket->data+RSA_SIZE-(KEY_SIZE+TIMESTAMP_SIZE),
+										pCipher->setKey(tmpRSABuff);
+										pCipher->crypt1(pMixPacket->data+RSA_SIZE,
+																				pMixPacket->data+RSA_SIZE-KEY_SIZE,
 																				DATA_SIZE-RSA_SIZE);
-										memcpy(pMixPacket->data,tmpRSABuff+KEY_SIZE+TIMESTAMP_SIZE,RSA_SIZE-(KEY_SIZE+TIMESTAMP_SIZE));
+										memcpy(pMixPacket->data,tmpRSABuff+KEY_SIZE,RSA_SIZE-KEY_SIZE);
+										getRandom(pMixPacket->data+DATA_SIZE-KEY_SIZE,KEY_SIZE);
 										m_pMiddleMixChannelList->add(pMixPacket->channel,pCipher,&channelOut);
 										pMixPacket->channel=channelOut;
 										#ifdef USE_POOL
-											pPool->pool(pMixPacket);
+											pPool->pool(pPoolEntry);
 										#endif
 										if(m_pMuxOut->send(pMixPacket)==SOCKET_ERROR)
 											goto ERR;
@@ -617,10 +633,10 @@ SINT32 CAMiddleMix::loop()
 						else
 							{//established connection
 									pMixPacket->channel=channelOut;
-									pCipher->decryptAES(pMixPacket->data,pMixPacket->data,DATA_SIZE);
+									pCipher->crypt1(pMixPacket->data,pMixPacket->data,DATA_SIZE);
 									pCipher->unlock();
 									#ifdef USE_POOL
-										pPool->pool(pMixPacket);
+										pPool->pool(pPoolEntry);
 									#endif
 									if(m_pMuxOut->send(pMixPacket)==SOCKET_ERROR)
 										goto ERR;
@@ -628,25 +644,31 @@ SINT32 CAMiddleMix::loop()
 					}
 			}
 ERR:
-		CAMsg::printMsg(LOG_CRIT,"Preparing for restart...\n");
+		CAMsg::printMsg(LOG_CRIT,"loop(): Preparing for restart...\n");
+		m_bRun=false;
 		m_pMuxIn->close();
 		m_pMuxOut->close();
 		oThread.join();		
 
-		CAMsg::printMsg(LOG_CRIT,"Seams that we are restarting now!!\n");
 		delete tmpRSABuff;
-		delete pMixPacket;
+		delete pPoolEntry;
 		#ifdef USE_POOL
 			delete pPool;
 		#endif
 #endif //!NEW_MIX_TYPE
+		CAMsg::printMsg(LOG_CRIT,"loop(): Seams that we are restarting now!!\n");
 		return E_UNKNOWN;
 	}
 SINT32 CAMiddleMix::clean()
-	{
+{
+    /*
 		if(m_pInfoService!=NULL)
+    {
+        m_pInfoService->stop();
 			delete m_pInfoService;
 		m_pInfoService=NULL;
+    }
+    */
 		if(m_pMuxIn!=NULL)
 			{
 				m_pMuxIn->close();
