@@ -144,9 +144,11 @@ bool CAMix::needAutoConfig()
     return ret;
 }
 
-/** This will initialize the XML Cascade Info that is sent to the InfoService
+/** This will initialize the XML Cascade Info struct @ref XMLFirstMixToInfoService that is sent to the InfoService
 * in \c CAInfoService::sendCascadeHelo()
-* @DOCME
+* @param mixes the <Mixes> element of the XML struct we received from the succeeding mix.
+* @retval E_UNKNOWN if processing produces an error
+* @retval E_SUCCESS otherwise
 */
 SINT32 CAMix::initMixCascadeInfo(DOM_Element& mixes)
 {
@@ -226,6 +228,15 @@ SINT32 CAMix::initMixCascadeInfo(DOM_Element& mixes)
     if(cascadeID != NULL)
 				setDOMElementAttribute(elemRoot,"id",cascadeID);
     setDOMElementAttribute(elemMixesDocCascade,"count",count);
-    return E_SUCCESS;
+    
+		
+  DOM_Node elemPayment=m_docMixCascadeInfo.createElement("Payment");
+	elemRoot.appendChild(elemPayment);
+#ifdef PAYMENT
+	setDOMElementAttribute(elemPayment,"required",(UINT8*)"true");
+#else
+	setDOMElementAttribute(elemPayment,"required",(UINT8*)"false");
+#endif
+		return E_SUCCESS;
 }
 
