@@ -27,11 +27,11 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 */
 #ifndef __CAMUTEX__
 #define __CAMUTEX__
-
 class CAConditionVariable;
 class CAMutex
 	{
 		public:
+#ifndef DEBUG
 			CAMutex()
 				{
 					m_pMutex=new pthread_mutex_t;
@@ -43,7 +43,10 @@ class CAMutex
 					pthread_mutex_destroy(m_pMutex);
 					delete m_pMutex;
 				}
-
+#else
+			CAMutex();
+			virtual ~CAMutex();
+#endif
 			SINT32 lock()
 				{
 					if(pthread_mutex_lock(m_pMutex)==0)
