@@ -371,16 +371,7 @@ SINT32 setDOMElementValue(DOM_Element& elem,UINT32 text)
 SINT32 setDOMElementValue(DOM_Element & elem, const UINT64 text)
 	{
 		UINT8 tmp[32];
-		#ifdef HAVE_NATIVE_UINT64
-			#ifdef HAVE_SNPRINTF
-				snprintf((char*)tmp, 31, "%llu", text);
-			#else
-				trio_snprintf((char*)tmp, 31, "%llu", text);
-			#endif
-		#else
-			#warning setDOMElementValue(uint64) is not implemented for this platform!!
-			return E_UNKNOWN;
-		#endif
+		print64(tmp,text);
 		setDOMElementValue(elem,tmp);
 		return E_SUCCESS;
 	}
@@ -567,7 +558,6 @@ SINT32 getDOMElementValue(const DOM_Element& elem,UINT32* value)
 
 SINT32 getDOMElementValue(const DOM_Element& elem, UINT64 &value)
 {
-	ASSERT(value!=NULL, "Value is null");
 	ASSERT(elem!=NULL, "Element is NULL");
 	UINT8 buf[256];
 	UINT32 bufLen = 256;
@@ -844,8 +834,8 @@ SINT32 parseU64(const UINT8 * str, UINT64& value)
 			return E_SUCCESS;
 		#else
 			#warning parseU64() is not implemented for platforms without atoll() support!!!
+			return E_UNKNOWN;
 		#endif
-		return E_UNKNOWN;
 	#else
 		#warning parseU64() is not implemented for platforms without native UINT64 support!!!
 		///@todo code if we do not have native UINT64
