@@ -84,7 +84,6 @@ SINT32 setDOMElementValue(DOM_Element& elem,const UINT8* value);
  * as null-terminated C String. If there is no text node
  * len is set to 0.
  * 
- * TODO: Why is elem a DOM_Node and not a DOM_Element here?
  * @param DOM_Node the element which has a text node under it
  * @param value a buffer that gets the text value
  * @param len on call contains the buffer size, on return contains the number of bytes copied
@@ -228,22 +227,6 @@ inline bool isZero64(UINT64& op1)
 #endif
 	}
 	
-/*inline void print64(UINT8* buff,UINT64& op)
-	{
-		#if defined(HAVE_NATIVE_UINT64)
-			#if defined(_WIN32)
-				_ui64toa(op,(char*)buff,10);
-			#elif defined(__linux)||defined(__sgi)||defined(__FreeBSD__) //TODO: check if for FreeBSD it is correct
-				sprintf((char*)buff,"%Lu",op);
-			#elif defined(__APPLE__) //TODO: Check if this is ok...
-				sprintf((char*)buff,"%llu",op);
-			#endif
-		#else //no native UINT_64
-			sprintf((char*)buff,"(%lu:%lu)",op.high,op.low);
-		#endif
-	}
-*/
-
 inline void print64(UINT8* buff,UINT64 num)
 	{
 		#ifdef HAVE_NATIVE_UINT64
