@@ -34,7 +34,7 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 #if !defined(AFX_STDAFX_H__9A5B051F_FF3A_11D3_9F5E_000001037024__INCLUDED_)
 #define AFX_STDAFX_H__9A5B051F_FF3A_11D3_9F5E_000001037024__INCLUDED_
 
-#define MIX_VERSION "00.03.99"
+#define MIX_VERSION "00.04.28"
 
 //Define all features if we are running in documentation creation mode
 #ifdef DOXYGEN
@@ -45,7 +45,7 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 	#define PAYMENT
 	#define HAVE_UNIX_DOMAIN_PROTOCOL
 	#define HAVE_EPOLL
-#endif	
+#endif
 
 #if defined(DEBUG)|| defined(_DEBUG)
 	#undef DEBUG
@@ -81,7 +81,7 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 	#else
 		#define DELAY_BUCKET_GROW_INTERVALL (1000/DELAY_CHANNEL_KBYTE_PER_SECOND) //Time in ms
 		#define DELAY_BUCKET_GROW PAYLOAD_SIZE //Grow in bytes
-	#endif	
+	#endif
 #endif
 #ifdef DELAY_USERS
 	#ifndef DELAY_USERS_TRAFFIC
@@ -96,7 +96,7 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 	#else
 		#define DELAY_USERS_BUCKET_GROW_INTERVALL 1000 //Time in ms
 		#define DELAY_USERS_BUCKET_GROW DELAY_USERS_PACKETS_PER_SECOND //Grow in bytes
-	#endif	
+	#endif
 #endif
 #ifdef DELAY_CHANNELS_LATENCY
 	#define DELAY_CHANNEL_LATENCY 10000 //min latency defaults to 10 second
@@ -112,7 +112,7 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 //#define NEW_FLOW_CONTROL //enable for the new flow control mechanism
 
 //#define REPLAY_DETECTION // enable to prevent replay of mix packets
-#define REPLAY_TIMESTAMP_PROPAGATION_INTERVALL 15 //How often (in minutes) should the current replay timestamps be propagate
+#define REPLAY_TIMESTAMP_PROPAGATION_INTERVALL 1 //How often (in minutes) should the current replay timestamps be propagate
 
 //#define DATABASE_PERFORMANCE_TEST //to performe a performance test of the replay db
 //Some constants
@@ -130,6 +130,10 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 
 #define MAX_USER_SEND_QUEUE 100000 //How many bytes could be in each User's send queue, before we suspend the belonging channels
 
+#define PAYMENT_ACCOUNT_CERT_TIMEOUT 180 //Timeout for receiving the Payment certificate in seconds
+#define CLEANUP_THREAD_SLEEP_INTERVAL 60 //sleep interval for payment blocked ip list
+#define BALANCE_REQUEST_TIMEOUT 60 //Timeout for Balance requests
+
 #define FLOW_CONTROL_SENDME_HARD_LIMIT 95 //last mix stops sending after this unack packets
 #define FLOW_CONTROL_SENDME_SOFT_LIMIT 80 //last mix sends request for 'SENDME' after this unack packets
 
@@ -145,6 +149,7 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 	#define LOG_PACKET_TIMES
 #endif
 
+#define MIX_CASCADE_PROTOCOL_VERSION_0_9 9  //with new payment protocol
 #define MIX_CASCADE_PROTOCOL_VERSION_0_8 8  //with replay detection + control channels + first mix symmetric
 #define MIX_CASCADE_PROTOCOL_VERSION_0_7 7  //with replay detection + control channels (obsolete)
 #define MIX_CASCADE_PROTOCOL_VERSION_0_6 6  //with new flow control
@@ -155,9 +160,11 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 
 #if (defined(LOG_CHANNEL)) && !defined(LOG_TRAFFIC_PER_USER)
 	#define LOG_TRAFFIC_PER_USER
-#endif	
+#endif
 #ifdef REPLAY_DETECTION
 	#define MIX_CASCADE_PROTOCOL_VERSION "0.8"
+#elif defined(PAYMENT)
+	#define MIX_CASCADE_PROTOCOL_VERSION "0.9"
 #else
 	#define MIX_CASCADE_PROTOCOL_VERSION "0.4"
 #endif
@@ -283,7 +290,7 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
   #include <memory.h>
   #include <sys/resource.h>
 	#include <ctype.h>
-    typedef struct sockaddr SOCKADDR;	
+    typedef struct sockaddr SOCKADDR;
   typedef SOCKADDR* LPSOCKADDR;
   #define SOCKET int
   typedef struct hostent HOSTENT;
@@ -329,7 +336,7 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 #define E_FILE_OPEN -500 //Error in opening a file
 #define E_FILE_READ -501 //Error in opening a file
 #define E_XML_PARSE -600 //Error in parsing XML
-#define E_NOT_CONNECTED -700 //Something is not connected that should be 
+#define E_NOT_CONNECTED -700 //Something is not connected that should be
 														// (like a TCP/IP connection or a database connection)
 #define E_NOT_FOUND -701 //Something was not found
 #define E_INVALID -800 // sth is invalid (e.g. signature verifying)
@@ -402,7 +409,7 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 #ifndef HAVE_O_SYNC
 	#ifdef HAVE_O_FSYNC
 		#define O_SYNC O_FSYNC
-	#else 
+	#else
 		#define	O_SYNC 0
 	#endif
 #endif
@@ -418,13 +425,25 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 #endif
 
 //For MySQL
-#if defined (PAYMENT_SUPPORT) ||defined(COUNTRY_STATS)
-#include <mysql/mysql.h>
+#if defined(COUNTRY_STATS)
+    #include <mysql/mysql.h>
 #endif
 
 //For Payment
 #ifdef PAYMENT
-	#include <postgresql/libpq-fe.h>
+	#ifdef HAVE_CONFIG_H
+		#ifdef HAVE_POSTGRESQL_LIBPQ_FE_H
+	    #include <postgresql/libpq-fe.h>
+		#elif defined(HAVE_PGSQL_LIBPQ_FE_H)
+	    #include <pgsql/libpq-fe.h>
+		#else
+	    #include <libpq-fe.h>
+		#endif
+  #elif defined(__FreeBSD__)
+		#include <libpq-fe.h>
+			#else
+		#include <postgresql/libpq-fe.h>
+  #endif
 #endif
 //Compressed Logs
 #ifdef COMPRESSED_LOGS
