@@ -172,17 +172,38 @@ SINT32 CAFirstMixA::loop()
 													}
 #ifdef PAYMENT
 												// payment code added by Bastian Voigt
-												if(m_pAccountingInstance->handleJapPacket( pMixPacket, pHashEntry ) != 1) 
+												SINT32 ret = CAAccountingInstance::handleJapPacket(pHashEntry );  
+												if (ret == 2)
+													{
+														goto NEXT_USER;
+													}													
+												if(ret == 3) 
 													{
 														// this jap is evil! terminate connection and add IP to blacklist
-														CAMsg::printMsg(LOG_DEBUG, "Detected evil Jap.. closing connection! Removing IP..\n\n");
+														CAMsg::printMsg(LOG_DEBUG, "Detected evil Jap.. closing connection! Removing IP..\n\n", ret);
+														fmChannelListEntry* pEntry;
+														pEntry=m_pChannelList->getFirstChannelForSocket(pMuxSocket);
+														while(pEntry!=NULL)
+															{
+																getRandom(pMixPacket->data,DATA_SIZE);
+																pMixPacket->flags=CHANNEL_CLOSE;
+																pMixPacket->channel=pEntry->channelOut;
+																#ifdef LOG_PACKET_TIMES
+																	setZero64(pQueueEntry->timestamp_proccessing_start);
+																#endif
+																m_pQueueSendToMix->add(pMixPacket,sizeof(tQueueEntry));
+																delete pEntry->pCipher;
+																pEntry=m_pChannelList->getNextChannel(pEntry);
+															}
 														m_pIPList->removeIP(pHashEntry->peerIP);
 														m_psocketgroupUsersRead->remove(*(CASocket*)pMuxSocket);
 														m_psocketgroupUsersWrite->remove(*(CASocket*)pMuxSocket);
 														delete pHashEntry->pQueueSend;
+														delete pHashEntry->pSymCipher;
 														m_pChannelList->remove(pMuxSocket);
 														delete pMuxSocket;
 														decUsers();
+														goto NEXT_USER;
 													}
 #endif
 												if(pMixPacket->flags==CHANNEL_DUMMY)					// just a dummy to keep the connection alife in e.g. NAT gateways 
@@ -460,9 +481,16 @@ NEXT_USER:
 								if(pfmHashEntry->uAlreadySendPacketSize==-1)
 									{
 										pfmHashEntry->pQueueSend->get((UINT8*)&pfmHashEntry->oQueueEntry,&len); 
+										#ifdef PAYMENT
+											//do not count control channel packets!
+											if(pfmHashEntry->oQueueEntry.packet.channel>0&&pfmHashEntry->oQueueEntry.packet.channel<256)
+												pfmHashEntry->bCountPacket=false;
+											else
+												pfmHashEntry->bCountPacket=true;
+										#endif
 										pfmHashEntry->pMuxSocket->prepareForSend(&(pfmHashEntry->oQueueEntry.packet));
 										pfmHashEntry->uAlreadySendPacketSize=0;
-									}
+										}
 								len=MIXPACKET_SIZE-pfmHashEntry->uAlreadySendPacketSize;
 								ret=((CASocket*)pfmHashEntry->pMuxSocket)->send(((UINT8*)&(pfmHashEntry->oQueueEntry))+pfmHashEntry->uAlreadySendPacketSize,len);
 								if(ret>0)
@@ -471,10 +499,11 @@ NEXT_USER:
 										if(pfmHashEntry->uAlreadySendPacketSize==MIXPACKET_SIZE)
 											{
 												#ifdef PAYMENT
-													// count packet for payment
-													CAAccountingInstance::getInstance()->handleJapPacket(
-															&(pfmHashEntry->oQueueEntry.packet),
-															pfmHashEntry);
+													if(pfmHashEntry->bCountPacket)
+														{
+															// count packet for payment
+															CAAccountingInstance::handleJapPacket(pfmHashEntry);
+														}
 												#endif
 												#ifdef DELAY_USERS
 													pfmHashEntry->delayBucket--;
