@@ -46,6 +46,7 @@ OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMA
 	#include "TypeB/CALastMixB.hpp"
 #endif
 #include "CALogPacketStats.hpp"
+#include "CATLSClientSocket.hpp"
 //#include "CAPayment.hpp"
 //#ifdef _WIN32
 //HANDLE hEventThreadEnde;
@@ -177,6 +178,7 @@ void init()
 		OpenSSL_add_all_algorithms();
 		pOpenSSLMutexes=new CAMutex[CRYPTO_num_locks()];
 		CRYPTO_set_locking_callback((void (*)(int,int,const char *,int))openssl_locking_callback);
+		SSL_library_init();
 		CAMsg::init();
 		CASocketAddrINet::init();
 		//startup
@@ -367,7 +369,7 @@ int main(int argc, const char* argv[])
 	{
 		pMix=NULL;
 		int i;
-		SINT32 maxFiles;
+		SINT32 maxFiles,ret;
 #if defined(HAVE_CRTDBG)
 //			_CrtSetReportMode( _CRT_WARN, _CRTDBG_MODE_FILE );
 //			_CrtSetReportFile( _CRT_WARN, _CRTDBG_FILE_STDOUT );
@@ -420,49 +422,19 @@ int main(int argc, const char* argv[])
 #ifdef _DEBUG
 			UINT32 start;
 #endif
-
-		//temp
-		/*for(;;){
-		CAQueue* pQueue=new CAQueue(MIXPACKET_SIZE);
-		UINT8 buff3[MIXPACKET_SIZE];
-		UINT64 t1,t2;
-		getcurrentTimeMicros(t1);
-		int h=1000;
-		for(int k=0;k<1000;k++)
-		{
-		for(int i=0;i<h;i++)
-			pQueue->add(buff3,MIXPACKET_SIZE);
-		UINT32 le=MIXPACKET_SIZE;
-		for(int i=0;i<h;i++)
-				pQueue->get(buff3,&le);
-				}
-		getcurrentTimeMicros(t2);
-		printf("Queue Time: %u s\n",diff64(t2,t1));
-		delete pQueue;
-		UINT8 buff23[MIXPACKET_SIZE*h];
-		UINT32 aktIndex=0;
-		getcurrentTimeMicros(t1);
-		for(int k=0;k<1000;k++)
-		{
-		aktIndex=0;
-		for(int i=0;i<h;i++)
-		{
-			memcpy(buff23+aktIndex,buff3,MIXPACKET_SIZE);
-			aktIndex+=MIXPACKET_SIZE;
-			}
-		for(int i=0;i<h;i++)
-		{
-			aktIndex-=MIXPACKET_SIZE;
-				memcpy(buff3,buff23+aktIndex,MIXPACKET_SIZE);
-				}
-				}
-		getcurrentTimeMicros(t2);
-		printf("Array Time: %u s\n",diff64(t2,t1));
-		}
+	/*	CATLSClientSocket ssl;
+		CASocketAddrINet addr;
+		addr.setAddr((const UINT8*)"127.0.0.1",(UINT16)3456);
+		UINT32 len1;
+		UINT8* pt=readFile((UINT8*)"/Users/sk13/Documents/projects/jap/testkey.der",&len1);
+		CACertificate* pCer=CACertificate::decode(pt,len1,CERT_DER);
+		ssl.setServerCertificate(pCer);
+		printf("try connect\n");
+		ssl.connect(addr,1,0);
+		ssl.receiveFully(pt,3);
 		
-		
-		exit(0);*/		
-		//end temp
+		exit(0);
+*/
 		if(options.parse(argc,argv) != E_SUCCESS)
 		{
 			CAMsg::printMsg(LOG_CRIT,"Error: Cannot parse configuration file!\n");
@@ -479,9 +451,52 @@ int main(int argc, const char* argv[])
 			}
 
 #ifdef DATABASE_PERFORMANCE_TEST
-			CADatabase::measurePerformance((UINT8*)"dbperformace.log",10000001,10000001,500000,1,100000);
+			CADatabase::measurePerformance((UINT8*)"dbperformace.log",1,10000001,500000,10,100000);
 			exit(0);
 #endif
+		UINT8 buff[255];
+#ifndef _WIN32
+		if(options.getDaemon())
+			{
+				CAMsg::printMsg(LOG_DEBUG,"starting as daemon\n");
+				pid_t pid;
+				CAMsg::printMsg(LOG_DEBUG,"daemon - before fork()\n");
+				pid=fork();
+				if(pid!=0)
+					{
+						CAMsg::printMsg(LOG_DEBUG,"Exiting parent!\n");
+						exit(EXIT_SUCCESS);
+					}		
+				CAMsg::printMsg(LOG_DEBUG,"child after fork...\n");
+				setsid();
+				#ifndef DO_TRACE
+					chdir("/");
+					umask(0);
+				#endif
+			}
+#endif
+		if(options.getLogDir((UINT8*)buff,255)==E_SUCCESS)
+			{
+				if(options.getCompressLogs())
+					CAMsg::setLogOptions(MSG_COMPRESSED_FILE);
+				else
+					CAMsg::setLogOptions(MSG_FILE);
+			}
+		ret=CAMsg::openEncryptedLog();
+#ifdef LOG_CRIME
+		if(ret!=E_SUCCESS)
+			{
+				if(options.isEncryptedLogEnabled())
+					{
+						CAMsg::printMsg(LOG_ERR,"Could not open encrypted log - exiting!\n");
+						exit(EXIT_FAILURE);
+					}
+				else
+					options.enableEncryptedLog(false);
+			}
+#endif
+
+
 #ifdef _DEBUG
 		//		CADatabase::test();
 		if(CAQueue::test()!=E_SUCCESS)
@@ -501,7 +516,6 @@ int main(int argc, const char* argv[])
 		//end Testin msSleep
 
 #endif
-		UINT8 buff[255];
 
 #ifndef WIN32
 		maxFiles=options.getMaxOpenFiles();
@@ -527,71 +541,6 @@ int main(int argc, const char* argv[])
 		if(geteuid()==0)
 			CAMsg::printMsg(LOG_INFO,"Warning - Running as root!\n");
 #endif
-		if(options.getDaemon())
-			{
-				CAMsg::printMsg(LOG_DEBUG,"starting as daemon\n");
-				#ifndef _WIN32
-					if(options.getLogDir(buff,255)==E_SUCCESS)
-						{
-							if(options.getCompressLogs())
-								CAMsg::setLogOptions(MSG_COMPRESSED_FILE);
-							else
-								CAMsg::setLogOptions(MSG_FILE);
-						}
-					else
-						CAMsg::setLogOptions(MSG_LOG);
-					SINT32 ret=CAMsg::openEncryptedLog();
-					#ifdef LOG_CRIME
-					if(ret!=E_SUCCESS)
-							{
-								if(options.isEncryptedLogEnabled())
-									{
-										CAMsg::printMsg(LOG_ERR,"Could not open encrypted log - exiting!\n");
-										exit(EXIT_FAILURE);
-									}
-								else
-									options.enableEncryptedLog(false);
-							}
-					#endif
-					pid_t pid;
-					CAMsg::printMsg(LOG_DEBUG,"daemon - before fork()\n");
-					pid=fork();
-					if(pid!=0)
-						{
-							CAMsg::printMsg(LOG_DEBUG,"Exiting parent!\n");
-							exit(EXIT_SUCCESS);
-						}		
-					CAMsg::printMsg(LOG_DEBUG,"child after fork...\n");
-					setsid();
-					#ifndef DO_TRACE
-					chdir("/");
-					umask(0);
-					#endif
-				#endif
-			}
-		else
-			{
-				if(options.getLogDir((UINT8*)buff,255)==E_SUCCESS)
-					{
-						if(options.getCompressLogs())
-							CAMsg::setLogOptions(MSG_COMPRESSED_FILE);
-						else
-							CAMsg::setLogOptions(MSG_FILE);
-					}
-				SINT32 ret=CAMsg::openEncryptedLog();
-				#ifdef LOG_CRIME
-					if(ret!=E_SUCCESS)
-							{
-								if(options.isEncryptedLogEnabled())
-									{
-										CAMsg::printMsg(LOG_ERR,"Could not open encrypted log - exiting!\n");
-										exit(EXIT_FAILURE);
-									}
-								else
-									options.enableEncryptedLog(false);
-							}
-#endif
-			}
 //			CAMsg::printMsg(LOG_ENCRYPTED,"Test: Anon proxy started!\n");
 //			CAMsg::printMsg(LOG_ENCRYPTED,"Test2: Anon proxy started!\n");
 //			CAMsg::printMsg(LOG_ENCRYPTED,"Test3: Anon proxy started!\n");
